type TypeGuard<T> = (value: unknown) => value is T;
/**
 * Helper utility that wraps a type guard with circular reference check.
 *
 * To illustrate the function of this cycle breaker, let's take a simple recursive type:
 *
 * @example
 * ```
 * interface Recursive {
 *   parent?: Recursive;
 * }
 * ```
 *
 * We can now create an object that matches that type but has a cycle:
 *
 * @example
 * ```
 * const node = {};
 * const recursive: Recursive = Object.assign(node, { parent: node });
 * ```
 *
 * If we didn't wrap the original type guard, it would be spinning in circles
 * until the maximum call stack exceeded error was thrown.
 *
 * @param typeName {TypeName} Name of the type (to be displayed in an error message)
 * @param typeGuard {TypeGuard} The original type guard
 * @returns {TypeGuard} The wrapped type guard
 */
declare function typeGuardCycleBreaker<T>(typeGuard: TypeGuard<T>): TypeGuard<T>;
export { typeGuardCycleBreaker };
